package com.mortals.xhx.module.holiday.web;

import com.mortals.xhx.base.system.param.service.ParamService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.*;
import com.mortals.framework.model.Context;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import com.mortals.framework.web.BaseCRUDJsonPhpController;
import com.mortals.xhx.module.holiday.model.HolidayEntity;
import com.mortals.xhx.module.holiday.model.HolidayQuery;
import com.mortals.xhx.module.holiday.service.HolidayService;
import org.apache.commons.lang3.ArrayUtils;
import com.mortals.framework.util.StringUtils;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import java.util.Arrays;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import static com.mortals.framework.ap.SysConstains.*;
/**
 *
 * 节假日
 *
 * @author zxfei
 * @date 2022-01-20
 */
@RestController
@RequestMapping("holiday")
public class HolidayController extends BaseCRUDJsonPhpController<HolidayService,HolidayForm,HolidayEntity,Long> {

    @Autowired
    private ParamService paramService;

    public HolidayController(){
        super.setFormClass(HolidayForm.class);
        super.setModuleDesc( "节假日");
    }

    @Override
    protected void init(HttpServletRequest request, HttpServletResponse response, HolidayForm form, Map<String, Object> model, Context context) {
        this.addDict(model, "workorholiday", paramService.getParamBySecondOrganize("Holiday","workorholiday"));
        super.init(request, response, form, model, context);
    }

    /**
     * 查询节假日
     */
    @PostMapping(value = "list")
    public String list(@RequestBody HolidayQuery query) {
        try {
            HolidayForm form = new HolidayForm();
            form.setQuery(query);
            return super.list(form);
        } catch (Exception e) {
            log.error("查询节假日列表错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 新增节假日
     */
    @PostMapping(value = "add")
    public String add() {
        try {
            HolidayForm form = new HolidayForm();
            return super.add(form);
        } catch (Exception e) {
            log.error("新增节假日错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 编辑节假日
     */
    @GetMapping(value = "edit")
    public String edit(Long id) {
        try {
            HolidayForm form = new HolidayForm();
            form.setId(new Long[]{id});
            return super.edit(form);
        } catch (Exception e) {
            log.error("节假日模块错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 保存节假日
     */
    @PostMapping(value = "save")
    public String save(@RequestBody HolidayEntity entity) {
        try {
            HolidayForm form = new HolidayForm();
            form.setHoliday(entity);
            return super.save(form);
        } catch (Exception e) {
            log.error("节假日模块错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 删除节假日
     */
    @GetMapping(value = "delete")
    public String delete(String id) {
        try {
            HolidayForm form = new HolidayForm();
            String[] split = id.split(",");
            Long[] ids = Arrays.asList(split).stream().map(Long::parseLong).toArray(Long[]::new);
            form.setId(ids);
            return super.delete(form);
        } catch (Exception e) {
            log.error("删除节假日错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 查看节假日
     */
    @GetMapping(value = "info")
    public String info(Long id) {
        try {
            HolidayForm form = new HolidayForm();
            form.setId(new Long[]{id});
            return super.view(form);
        } catch (Exception e) {
            log.error("查看节假日错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }


    /**
     * 节假日导入模板下载
     */
    @PostMapping(value = "downloadTemplate")
    public void downloadTemplate() {
        try {
            super.downloadTemplate();
        } catch (Exception e) {
            log.error("节假日导入模板下载错误", e);
        }
    }

    /**
     * 节假日导出
     */
    @PostMapping(value = "importData")
    public String importData(MultipartFile file, boolean updateSupport) {
        try {
            return super.importData(file, updateSupport);
        } catch (Exception e) {
            log.error("节假日导入错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 节假日导出
     */
    @PostMapping("exportExcel")
    public void exportExcel(@RequestBody HolidayQuery query) {
        try {
            HolidayForm form = new HolidayForm();
            form.setQuery(query);
            super.exportExcel(form);
        } catch (Exception e) {
            log.error("节假日导出错误", e);
        }
    }
}