package com.mortals.xhx.module.matter.web;

import com.mortals.xhx.base.system.param.service.ParamService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.*;
import com.mortals.framework.model.Context;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import com.mortals.framework.web.BaseCRUDJsonPhpController;
import com.mortals.xhx.module.matter.model.MatterChargesEntity;
import com.mortals.xhx.module.matter.model.MatterChargesQuery;
import com.mortals.xhx.module.matter.service.MatterChargesService;
import org.apache.commons.lang3.ArrayUtils;
import com.mortals.framework.util.StringUtils;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import java.util.Arrays;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import static com.mortals.framework.ap.SysConstains.*;
/**
 *
 * 事项收费标准
 *
 * @author zxfei
 * @date 2022-01-20
 */
@RestController
@RequestMapping("matter/charges")
public class MatterChargesController extends BaseCRUDJsonPhpController<MatterChargesService,MatterChargesForm,MatterChargesEntity,Long> {

    @Autowired
    private ParamService paramService;

    public MatterChargesController(){
        super.setFormClass(MatterChargesForm.class);
        super.setModuleDesc( "事项收费标准");
    }

    @Override
    protected void init(HttpServletRequest request, HttpServletResponse response, MatterChargesForm form, Map<String, Object> model, Context context) {
        this.addDict(model, "source", paramService.getParamBySecondOrganize("MatterCharges","source"));
        super.init(request, response, form, model, context);
    }

    /**
     * 查询事项收费标准
     */
    @PostMapping(value = "list")
    public String list(@RequestBody MatterChargesQuery query) {
        try {
            MatterChargesForm form = new MatterChargesForm();
            form.setQuery(query);
            return super.list(form);
        } catch (Exception e) {
            log.error("查询事项收费标准列表错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 新增事项收费标准
     */
    @PostMapping(value = "add")
    public String add() {
        try {
            MatterChargesForm form = new MatterChargesForm();
            return super.add(form);
        } catch (Exception e) {
            log.error("新增事项收费标准错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 编辑事项收费标准
     */
    @GetMapping(value = "edit")
    public String edit(Long id) {
        try {
            MatterChargesForm form = new MatterChargesForm();
            form.setId(new Long[]{id});
            return super.edit(form);
        } catch (Exception e) {
            log.error("事项收费标准模块错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 保存事项收费标准
     */
    @PostMapping(value = "save")
    public String save(@RequestBody MatterChargesEntity entity) {
        try {
            MatterChargesForm form = new MatterChargesForm();
            form.setMatterCharges(entity);
            return super.save(form);
        } catch (Exception e) {
            log.error("事项收费标准模块错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 删除事项收费标准
     */
    @GetMapping(value = "delete")
    public String delete(String id) {
        try {
            MatterChargesForm form = new MatterChargesForm();
            String[] split = id.split(",");
            Long[] ids = Arrays.asList(split).stream().map(Long::parseLong).toArray(Long[]::new);
            form.setId(ids);
            return super.delete(form);
        } catch (Exception e) {
            log.error("删除事项收费标准错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 查看事项收费标准
     */
    @GetMapping(value = "info")
    public String info(Long id) {
        try {
            MatterChargesForm form = new MatterChargesForm();
            form.setId(new Long[]{id});
            return super.view(form);
        } catch (Exception e) {
            log.error("查看事项收费标准错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }


    /**
     * 事项收费标准导入模板下载
     */
    @PostMapping(value = "downloadTemplate")
    public void downloadTemplate() {
        try {
            super.downloadTemplate();
        } catch (Exception e) {
            log.error("事项收费标准导入模板下载错误", e);
        }
    }

    /**
     * 事项收费标准导出
     */
    @PostMapping(value = "importData")
    public String importData(MultipartFile file, boolean updateSupport) {
        try {
            return super.importData(file, updateSupport);
        } catch (Exception e) {
            log.error("事项收费标准导入错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 事项收费标准导出
     */
    @PostMapping("exportExcel")
    public void exportExcel(@RequestBody MatterChargesQuery query) {
        try {
            MatterChargesForm form = new MatterChargesForm();
            form.setQuery(query);
            super.exportExcel(form);
        } catch (Exception e) {
            log.error("事项收费标准导出错误", e);
        }
    }
}