package com.mortals.xhx.module.matter.web;

import com.mortals.xhx.base.system.param.service.ParamService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.*;
import com.mortals.framework.model.Context;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import com.mortals.framework.web.BaseCRUDJsonPhpController;
import com.mortals.xhx.module.matter.model.MatterDatumEntity;
import com.mortals.xhx.module.matter.model.MatterDatumQuery;
import com.mortals.xhx.module.matter.service.MatterDatumService;
import org.apache.commons.lang3.ArrayUtils;
import com.mortals.framework.util.StringUtils;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import java.util.Arrays;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import static com.mortals.framework.ap.SysConstains.*;
/**
 *
 * 事项申请材料
 *
 * @author zxfei
 * @date 2022-01-20
 */
@RestController
@RequestMapping("matter/datum")
public class MatterDatumController extends BaseCRUDJsonPhpController<MatterDatumService,MatterDatumForm,MatterDatumEntity,Long> {

    @Autowired
    private ParamService paramService;

    public MatterDatumController(){
        super.setFormClass(MatterDatumForm.class);
        super.setModuleDesc( "事项申请材料");
    }

    @Override
    protected void init(HttpServletRequest request, HttpServletResponse response, MatterDatumForm form, Map<String, Object> model, Context context) {
        this.addDict(model, "isMust", paramService.getParamBySecondOrganize("MatterDatum","isMust"));
        this.addDict(model, "materialType", paramService.getParamBySecondOrganize("MatterDatum","materialType"));
        this.addDict(model, "materialProperty", paramService.getParamBySecondOrganize("MatterDatum","materialProperty"));
        this.addDict(model, "electronicgs", paramService.getParamBySecondOrganize("MatterDatum","electronicgs"));
        this.addDict(model, "materialSource", paramService.getParamBySecondOrganize("MatterDatum","materialSource"));
        this.addDict(model, "paperNum", paramService.getParamBySecondOrganize("MatterDatum","paperNum"));
        this.addDict(model, "jianmMs", paramService.getParamBySecondOrganize("MatterDatum","jianmMs"));
        this.addDict(model, "isjianm", paramService.getParamBySecondOrganize("MatterDatum","isjianm"));
        this.addDict(model, "isLack", paramService.getParamBySecondOrganize("MatterDatum","isLack"));
        this.addDict(model, "source", paramService.getParamBySecondOrganize("MatterDatum","source"));
        super.init(request, response, form, model, context);
    }

    /**
     * 查询事项申请材料
     */
    @PostMapping(value = "list")
    public String list(@RequestBody MatterDatumQuery query) {
        try {
            MatterDatumForm form = new MatterDatumForm();
            form.setQuery(query);
            return super.list(form);
        } catch (Exception e) {
            log.error("查询事项申请材料列表错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 新增事项申请材料
     */
    @PostMapping(value = "add")
    public String add() {
        try {
            MatterDatumForm form = new MatterDatumForm();
            return super.add(form);
        } catch (Exception e) {
            log.error("新增事项申请材料错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 编辑事项申请材料
     */
    @GetMapping(value = "edit")
    public String edit(Long id) {
        try {
            MatterDatumForm form = new MatterDatumForm();
            form.setId(new Long[]{id});
            return super.edit(form);
        } catch (Exception e) {
            log.error("事项申请材料模块错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 保存事项申请材料
     */
    @PostMapping(value = "save")
    public String save(@RequestBody MatterDatumEntity entity) {
        try {
            MatterDatumForm form = new MatterDatumForm();
            form.setMatterDatum(entity);
            return super.save(form);
        } catch (Exception e) {
            log.error("事项申请材料模块错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 删除事项申请材料
     */
    @GetMapping(value = "delete")
    public String delete(String id) {
        try {
            MatterDatumForm form = new MatterDatumForm();
            String[] split = id.split(",");
            Long[] ids = Arrays.asList(split).stream().map(Long::parseLong).toArray(Long[]::new);
            form.setId(ids);
            return super.delete(form);
        } catch (Exception e) {
            log.error("删除事项申请材料错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 查看事项申请材料
     */
    @GetMapping(value = "info")
    public String info(Long id) {
        try {
            MatterDatumForm form = new MatterDatumForm();
            form.setId(new Long[]{id});
            return super.view(form);
        } catch (Exception e) {
            log.error("查看事项申请材料错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }


    /**
     * 事项申请材料导入模板下载
     */
    @PostMapping(value = "downloadTemplate")
    public void downloadTemplate() {
        try {
            super.downloadTemplate();
        } catch (Exception e) {
            log.error("事项申请材料导入模板下载错误", e);
        }
    }

    /**
     * 事项申请材料导出
     */
    @PostMapping(value = "importData")
    public String importData(MultipartFile file, boolean updateSupport) {
        try {
            return super.importData(file, updateSupport);
        } catch (Exception e) {
            log.error("事项申请材料导入错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 事项申请材料导出
     */
    @PostMapping("exportExcel")
    public void exportExcel(@RequestBody MatterDatumQuery query) {
        try {
            MatterDatumForm form = new MatterDatumForm();
            form.setQuery(query);
            super.exportExcel(form);
        } catch (Exception e) {
            log.error("事项申请材料导出错误", e);
        }
    }
}