package com.mortals.xhx.module.matter.web;

import com.mortals.xhx.base.system.param.service.ParamService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.*;
import com.mortals.framework.model.Context;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import com.mortals.framework.web.BaseCRUDJsonPhpController;
import com.mortals.xhx.module.matter.model.MatterIntermediaryEntity;
import com.mortals.xhx.module.matter.model.MatterIntermediaryQuery;
import com.mortals.xhx.module.matter.service.MatterIntermediaryService;
import org.apache.commons.lang3.ArrayUtils;
import com.mortals.framework.util.StringUtils;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import java.util.Arrays;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import static com.mortals.framework.ap.SysConstains.*;
/**
 *
 * 事项中介服务
 *
 * @author zxfei
 * @date 2022-01-20
 */
@RestController
@RequestMapping("matter/intermediary")
public class MatterIntermediaryController extends BaseCRUDJsonPhpController<MatterIntermediaryService,MatterIntermediaryForm,MatterIntermediaryEntity,Long> {

    @Autowired
    private ParamService paramService;

    public MatterIntermediaryController(){
        super.setFormClass(MatterIntermediaryForm.class);
        super.setModuleDesc( "事项中介服务");
    }

    @Override
    protected void init(HttpServletRequest request, HttpServletResponse response, MatterIntermediaryForm form, Map<String, Object> model, Context context) {
        this.addDict(model, "source", paramService.getParamBySecondOrganize("MatterIntermediary","source"));
        super.init(request, response, form, model, context);
    }

    /**
     * 查询事项中介服务
     */
    @PostMapping(value = "list")
    public String list(@RequestBody MatterIntermediaryQuery query) {
        try {
            MatterIntermediaryForm form = new MatterIntermediaryForm();
            form.setQuery(query);
            return super.list(form);
        } catch (Exception e) {
            log.error("查询事项中介服务列表错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 新增事项中介服务
     */
    @PostMapping(value = "add")
    public String add() {
        try {
            MatterIntermediaryForm form = new MatterIntermediaryForm();
            return super.add(form);
        } catch (Exception e) {
            log.error("新增事项中介服务错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 编辑事项中介服务
     */
    @GetMapping(value = "edit")
    public String edit(Long id) {
        try {
            MatterIntermediaryForm form = new MatterIntermediaryForm();
            form.setId(new Long[]{id});
            return super.edit(form);
        } catch (Exception e) {
            log.error("事项中介服务模块错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 保存事项中介服务
     */
    @PostMapping(value = "save")
    public String save(@RequestBody MatterIntermediaryEntity entity) {
        try {
            MatterIntermediaryForm form = new MatterIntermediaryForm();
            form.setMatterIntermediary(entity);
            return super.save(form);
        } catch (Exception e) {
            log.error("事项中介服务模块错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 删除事项中介服务
     */
    @GetMapping(value = "delete")
    public String delete(String id) {
        try {
            MatterIntermediaryForm form = new MatterIntermediaryForm();
            String[] split = id.split(",");
            Long[] ids = Arrays.asList(split).stream().map(Long::parseLong).toArray(Long[]::new);
            form.setId(ids);
            return super.delete(form);
        } catch (Exception e) {
            log.error("删除事项中介服务错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 查看事项中介服务
     */
    @GetMapping(value = "info")
    public String info(Long id) {
        try {
            MatterIntermediaryForm form = new MatterIntermediaryForm();
            form.setId(new Long[]{id});
            return super.view(form);
        } catch (Exception e) {
            log.error("查看事项中介服务错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }


    /**
     * 事项中介服务导入模板下载
     */
    @PostMapping(value = "downloadTemplate")
    public void downloadTemplate() {
        try {
            super.downloadTemplate();
        } catch (Exception e) {
            log.error("事项中介服务导入模板下载错误", e);
        }
    }

    /**
     * 事项中介服务导出
     */
    @PostMapping(value = "importData")
    public String importData(MultipartFile file, boolean updateSupport) {
        try {
            return super.importData(file, updateSupport);
        } catch (Exception e) {
            log.error("事项中介服务导入错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 事项中介服务导出
     */
    @PostMapping("exportExcel")
    public void exportExcel(@RequestBody MatterIntermediaryQuery query) {
        try {
            MatterIntermediaryForm form = new MatterIntermediaryForm();
            form.setQuery(query);
            super.exportExcel(form);
        } catch (Exception e) {
            log.error("事项中介服务导出错误", e);
        }
    }
}