package com.mortals.xhx.module.site.web;

import com.mortals.xhx.base.system.param.service.ParamService;
import com.mortals.xhx.module.model.model.ModelQuery;
import com.mortals.xhx.module.model.service.ModelService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.*;
import com.mortals.framework.model.Context;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import com.mortals.framework.web.BaseCRUDJsonPhpController;
import com.mortals.xhx.module.site.model.SiteEntity;
import com.mortals.xhx.module.site.model.SiteQuery;
import com.mortals.xhx.module.site.service.SiteService;
import org.apache.commons.lang3.ArrayUtils;
import com.mortals.framework.util.StringUtils;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import java.util.Arrays;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import static com.mortals.framework.ap.SysConstains.*;
/**
 *
 * 站点
 *
 * @author zxfei
 * @date 2022-01-20
 */
@RestController
@RequestMapping("site")
public class  SiteController extends BaseCRUDJsonPhpController<SiteService,SiteForm,SiteEntity,Long> {

    @Autowired
    private ParamService paramService;
    @Autowired
    private ModelService modelService;

    public SiteController(){
        super.setFormClass(SiteForm.class);
        super.setModuleDesc( "站点");
    }

    @Override
    protected void init(HttpServletRequest request, HttpServletResponse response, SiteForm form, Map<String, Object> model, Context context) {
        this.addDict(model, "haveSonArea", paramService.getParamBySecondOrganize("Site","haveSonArea"));
        this.addDict(model, "workday1", paramService.getParamBySecondOrganize("Site","workday1"));
        this.addDict(model, "workday2", paramService.getParamBySecondOrganize("Site","workday2"));
        this.addDict(model, "workday3", paramService.getParamBySecondOrganize("Site","workday3"));
        this.addDict(model, "workday4", paramService.getParamBySecondOrganize("Site","workday4"));
        this.addDict(model, "workday5", paramService.getParamBySecondOrganize("Site","workday5"));
        this.addDict(model, "workday6", paramService.getParamBySecondOrganize("Site","workday6"));
        this.addDict(model, "workday7", paramService.getParamBySecondOrganize("Site","workday7"));
        this.addDict(model, "level", paramService.getParamBySecondOrganize("Site","level"));
        this.addDict(model, "building", paramService.getParamBySecondOrganize("Site","building"));
        this.addDict(model, "isSite", paramService.getParamBySecondOrganize("Site","isSite"));
        this.addDict(model, "status", paramService.getParamBySecondOrganize("Site","status"));
        this.addDict(model, "modelIds", modelService.find(new ModelQuery()).stream().collect(Collectors.toMap(x->x.getId().toString(), y->y.getModelName())));
        super.init(request, response, form, model, context);
    }

    /**
     * 查询站点
     */
    @PostMapping(value = "list")
    public String list(@RequestBody SiteQuery query) {
        try {
            SiteForm form = new SiteForm();
            form.setQuery(query);
            return super.list(form);
        } catch (Exception e) {
            log.error("查询站点列表错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 新增站点
     */
    @PostMapping(value = "add")
    public String add() {
        try {
            SiteForm form = new SiteForm();
            return super.add(form);
        } catch (Exception e) {
            log.error("新增站点错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 编辑站点
     */
    @GetMapping(value = "edit")
    public String edit(Long id) {
        try {
            SiteForm form = new SiteForm();
            form.setId(new Long[]{id});
            return super.edit(form);
        } catch (Exception e) {
            log.error("站点模块错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 保存站点
     */
    @PostMapping(value = "save")
    public String save(@RequestBody SiteEntity entity) {
        try {
            SiteForm form = new SiteForm();
            form.setSite(entity);
            return super.save(form);
        } catch (Exception e) {
            log.error("站点模块错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 删除站点
     */
    @GetMapping(value = "delete")
    public String delete(String id) {
        try {
            SiteForm form = new SiteForm();
            String[] split = id.split(",");
            Long[] ids = Arrays.asList(split).stream().map(Long::parseLong).toArray(Long[]::new);
            form.setId(ids);
            return super.delete(form);
        } catch (Exception e) {
            log.error("删除站点错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 查看站点
     */
    @GetMapping(value = "info")
    public String info(Long id) {
        try {
            SiteForm form = new SiteForm();
            form.setId(new Long[]{id});
            return super.view(form);
        } catch (Exception e) {
            log.error("查看站点错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }


    /**
     * 站点导入模板下载
     */
    @PostMapping(value = "downloadTemplate")
    public void downloadTemplate() {
        try {
            super.downloadTemplate();
        } catch (Exception e) {
            log.error("站点导入模板下载错误", e);
        }
    }

    /**
     * 站点导出
     */
    @PostMapping(value = "importData")
    public String importData(MultipartFile file, boolean updateSupport) {
        try {
            return super.importData(file, updateSupport);
        } catch (Exception e) {
            log.error("站点导入错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 站点导出
     */
    @PostMapping("exportExcel")
    public void exportExcel(@RequestBody SiteQuery query) {
        try {
            SiteForm form = new SiteForm();
            form.setQuery(query);
            super.exportExcel(form);
        } catch (Exception e) {
            log.error("站点导出错误", e);
        }
    }
}