package com.mortals.xhx.module.site.web;

import com.mortals.xhx.base.system.param.service.ParamService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.*;
import com.mortals.framework.model.Context;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import com.mortals.framework.web.BaseCRUDJsonPhpController;
import com.mortals.xhx.module.site.model.SiteModelEntity;
import com.mortals.xhx.module.site.model.SiteModelQuery;
import com.mortals.xhx.module.site.service.SiteModelService;
import org.apache.commons.lang3.ArrayUtils;
import com.mortals.framework.util.StringUtils;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import java.util.Arrays;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import static com.mortals.framework.ap.SysConstains.*;
/**
 *
 * 站点模块
 *
 * @author zxfei
 * @date 2022-01-20
 */
@RestController
@RequestMapping("site/model")
public class SiteModelController extends BaseCRUDJsonPhpController<SiteModelService,SiteModelForm,SiteModelEntity,Long> {

    @Autowired
    private ParamService paramService;

    public SiteModelController(){
        super.setFormClass(SiteModelForm.class);
        super.setModuleDesc( "站点模块");
    }

    @Override
    protected void init(HttpServletRequest request, HttpServletResponse response, SiteModelForm form, Map<String, Object> model, Context context) {
        super.init(request, response, form, model, context);
    }

    /**
     * 查询站点模块
     */
    @PostMapping(value = "list")
    public String list(@RequestBody SiteModelQuery query) {
        try {
            SiteModelForm form = new SiteModelForm();
            form.setQuery(query);
            return super.list(form);
        } catch (Exception e) {
            log.error("查询站点模块列表错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 新增站点模块
     */
    @PostMapping(value = "add")
    public String add() {
        try {
            SiteModelForm form = new SiteModelForm();
            return super.add(form);
        } catch (Exception e) {
            log.error("新增站点模块错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 编辑站点模块
     */
    @GetMapping(value = "edit")
    public String edit(Long id) {
        try {
            SiteModelForm form = new SiteModelForm();
            form.setId(new Long[]{id});
            return super.edit(form);
        } catch (Exception e) {
            log.error("站点模块模块错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 保存站点模块
     */
    @PostMapping(value = "save")
    public String save(@RequestBody SiteModelEntity entity) {
        try {
            SiteModelForm form = new SiteModelForm();
            form.setSiteModel(entity);
            return super.save(form);
        } catch (Exception e) {
            log.error("站点模块模块错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 删除站点模块
     */
    @GetMapping(value = "delete")
    public String delete(String id) {
        try {
            SiteModelForm form = new SiteModelForm();
            String[] split = id.split(",");
            Long[] ids = Arrays.asList(split).stream().map(Long::parseLong).toArray(Long[]::new);
            form.setId(ids);
            return super.delete(form);
        } catch (Exception e) {
            log.error("删除站点模块错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 查看站点模块
     */
    @GetMapping(value = "info")
    public String info(Long id) {
        try {
            SiteModelForm form = new SiteModelForm();
            form.setId(new Long[]{id});
            return super.view(form);
        } catch (Exception e) {
            log.error("查看站点模块错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }


    /**
     * 站点模块导入模板下载
     */
    @PostMapping(value = "downloadTemplate")
    public void downloadTemplate() {
        try {
            super.downloadTemplate();
        } catch (Exception e) {
            log.error("站点模块导入模板下载错误", e);
        }
    }

    /**
     * 站点模块导出
     */
    @PostMapping(value = "importData")
    public String importData(MultipartFile file, boolean updateSupport) {
        try {
            return super.importData(file, updateSupport);
        } catch (Exception e) {
            log.error("站点模块导入错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 站点模块导出
     */
    @PostMapping("exportExcel")
    public void exportExcel(@RequestBody SiteModelQuery query) {
        try {
            SiteModelForm form = new SiteModelForm();
            form.setQuery(query);
            super.exportExcel(form);
        } catch (Exception e) {
            log.error("站点模块导出错误", e);
        }
    }
}