package com.mortals.xhx.module.sms.web;

import com.mortals.xhx.base.system.param.service.ParamService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.*;
import com.mortals.framework.model.Context;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import com.mortals.framework.web.BaseCRUDJsonPhpController;
import com.mortals.xhx.module.sms.model.SmsSetEntity;
import com.mortals.xhx.module.sms.model.SmsSetQuery;
import com.mortals.xhx.module.sms.service.SmsSetService;
import org.apache.commons.lang3.ArrayUtils;
import com.mortals.framework.util.StringUtils;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import java.util.Arrays;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import static com.mortals.framework.ap.SysConstains.*;
/**
 *
 * 短信设置
 *
 * @author zxfei
 * @date 2022-01-20
 */
@RestController
@RequestMapping("sms/set")
public class SmsSetController extends BaseCRUDJsonPhpController<SmsSetService,SmsSetForm,SmsSetEntity,Long> {

    @Autowired
    private ParamService paramService;

    public SmsSetController(){
        super.setFormClass(SmsSetForm.class);
        super.setModuleDesc( "短信设置");
    }

    @Override
    protected void init(HttpServletRequest request, HttpServletResponse response, SmsSetForm form, Map<String, Object> model, Context context) {
        this.addDict(model, "messageoff", paramService.getParamBySecondOrganize("SmsSet","messageoff"));
        this.addDict(model, "smsplatform", paramService.getParamBySecondOrganize("SmsSet","smsplatform"));
        super.init(request, response, form, model, context);
    }

    /**
     * 查询短信设置
     */
    @PostMapping(value = "list")
    public String list(@RequestBody SmsSetQuery query) {
        try {
            SmsSetForm form = new SmsSetForm();
            form.setQuery(query);
            return super.list(form);
        } catch (Exception e) {
            log.error("查询短信设置列表错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 新增短信设置
     */
    @PostMapping(value = "add")
    public String add() {
        try {
            SmsSetForm form = new SmsSetForm();
            return super.add(form);
        } catch (Exception e) {
            log.error("新增短信设置错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 编辑短信设置
     */
    @GetMapping(value = "edit")
    public String edit(Long id) {
        try {
            SmsSetForm form = new SmsSetForm();
            form.setId(new Long[]{id});
            return super.edit(form);
        } catch (Exception e) {
            log.error("短信设置模块错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 保存短信设置
     */
    @PostMapping(value = "save")
    public String save(@RequestBody SmsSetEntity entity) {
        try {
            SmsSetForm form = new SmsSetForm();
            form.setSmsSet(entity);
            return super.save(form);
        } catch (Exception e) {
            log.error("短信设置模块错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 删除短信设置
     */
    @GetMapping(value = "delete")
    public String delete(String id) {
        try {
            SmsSetForm form = new SmsSetForm();
            String[] split = id.split(",");
            Long[] ids = Arrays.asList(split).stream().map(Long::parseLong).toArray(Long[]::new);
            form.setId(ids);
            return super.delete(form);
        } catch (Exception e) {
            log.error("删除短信设置错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 查看短信设置
     */
    @GetMapping(value = "info")
    public String info(Long id) {
        try {
            SmsSetForm form = new SmsSetForm();
            form.setId(new Long[]{id});
            return super.view(form);
        } catch (Exception e) {
            log.error("查看短信设置错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }


    /**
     * 短信设置导入模板下载
     */
    @PostMapping(value = "downloadTemplate")
    public void downloadTemplate() {
        try {
            super.downloadTemplate();
        } catch (Exception e) {
            log.error("短信设置导入模板下载错误", e);
        }
    }

    /**
     * 短信设置导出
     */
    @PostMapping(value = "importData")
    public String importData(MultipartFile file, boolean updateSupport) {
        try {
            return super.importData(file, updateSupport);
        } catch (Exception e) {
            log.error("短信设置导入错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 短信设置导出
     */
    @PostMapping("exportExcel")
    public void exportExcel(@RequestBody SmsSetQuery query) {
        try {
            SmsSetForm form = new SmsSetForm();
            form.setQuery(query);
            super.exportExcel(form);
        } catch (Exception e) {
            log.error("短信设置导出错误", e);
        }
    }
}