package com.mortals.xhx.module.window.web;

import com.mortals.xhx.base.system.param.service.ParamService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.*;
import com.mortals.framework.model.Context;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import com.mortals.framework.web.BaseCRUDJsonPhpController;
import com.mortals.xhx.module.window.model.WindowMatterEntity;
import com.mortals.xhx.module.window.model.WindowMatterQuery;
import com.mortals.xhx.module.window.service.WindowMatterService;
import org.apache.commons.lang3.ArrayUtils;
import com.mortals.framework.util.StringUtils;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import java.util.Arrays;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import static com.mortals.framework.ap.SysConstains.*;
/**
 *
 * 窗口事项
 *
 * @author zxfei
 * @date 2022-01-20
 */
@RestController
@RequestMapping("window/matter")
public class WindowMatterController extends BaseCRUDJsonPhpController<WindowMatterService,WindowMatterForm,WindowMatterEntity,Long> {

    @Autowired
    private ParamService paramService;

    public WindowMatterController(){
        super.setFormClass(WindowMatterForm.class);
        super.setModuleDesc( "窗口事项");
    }

    @Override
    protected void init(HttpServletRequest request, HttpServletResponse response, WindowMatterForm form, Map<String, Object> model, Context context) {
        super.init(request, response, form, model, context);
    }

    /**
     * 查询窗口事项
     */
    @PostMapping(value = "list")
    public String list(@RequestBody WindowMatterQuery query) {
        try {
            WindowMatterForm form = new WindowMatterForm();
            form.setQuery(query);
            return super.list(form);
        } catch (Exception e) {
            log.error("查询窗口事项列表错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 新增窗口事项
     */
    @PostMapping(value = "add")
    public String add() {
        try {
            WindowMatterForm form = new WindowMatterForm();
            return super.add(form);
        } catch (Exception e) {
            log.error("新增窗口事项错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 编辑窗口事项
     */
    @GetMapping(value = "edit")
    public String edit(Long id) {
        try {
            WindowMatterForm form = new WindowMatterForm();
            form.setId(new Long[]{id});
            return super.edit(form);
        } catch (Exception e) {
            log.error("窗口事项模块错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 保存窗口事项
     */
    @PostMapping(value = "save")
    public String save(@RequestBody WindowMatterEntity entity) {
        try {
            WindowMatterForm form = new WindowMatterForm();
            form.setWindowMatter(entity);
            return super.save(form);
        } catch (Exception e) {
            log.error("窗口事项模块错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 删除窗口事项
     */
    @GetMapping(value = "delete")
    public String delete(String id) {
        try {
            WindowMatterForm form = new WindowMatterForm();
            String[] split = id.split(",");
            Long[] ids = Arrays.asList(split).stream().map(Long::parseLong).toArray(Long[]::new);
            form.setId(ids);
            return super.delete(form);
        } catch (Exception e) {
            log.error("删除窗口事项错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 查看窗口事项
     */
    @GetMapping(value = "info")
    public String info(Long id) {
        try {
            WindowMatterForm form = new WindowMatterForm();
            form.setId(new Long[]{id});
            return super.view(form);
        } catch (Exception e) {
            log.error("查看窗口事项错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }


    /**
     * 窗口事项导入模板下载
     */
    @PostMapping(value = "downloadTemplate")
    public void downloadTemplate() {
        try {
            super.downloadTemplate();
        } catch (Exception e) {
            log.error("窗口事项导入模板下载错误", e);
        }
    }

    /**
     * 窗口事项导出
     */
    @PostMapping(value = "importData")
    public String importData(MultipartFile file, boolean updateSupport) {
        try {
            return super.importData(file, updateSupport);
        } catch (Exception e) {
            log.error("窗口事项导入错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 窗口事项导出
     */
    @PostMapping("exportExcel")
    public void exportExcel(@RequestBody WindowMatterQuery query) {
        try {
            WindowMatterForm form = new WindowMatterForm();
            form.setQuery(query);
            super.exportExcel(form);
        } catch (Exception e) {
            log.error("窗口事项导出错误", e);
        }
    }
}